@@ -30,7 +30,7 @@ def pulsing_light_func(light):
     Tuple(Color, Color)
         The ring, fill colors of the light.
     """
-    rate = getattr(light, 'rate')
+    rate = getattr(light, '_rate', 200)
     ring = WHITE
 
     time = pygame.time.get_ticks()
@@ -81,3 +81,11 @@ def fake_data_graph_function(graph, size):
     # Return what was asked for
     return [{"color": LCARS_PINK, "data": fake_data_1[-size:]},
             {"color": LCARS_BLUE, "data": fake_data_2[-size:]}, ]
+
+
+def go_to_page(pages, name):
+    for page in pages:
+        if page.name == name:
+            return page
+    print(f"Page {name!r} not found.")
+    return None
\ No newline at end of file
